@@ -68,9 +68,9 @@ class Result(object):
         """
         raise NotImplementedError
 
-    def get_map(self):
+    def get_data(self):
         """
-        Returns the element's property map.
+        Returns the element's property data.
 
         :rtype: dict
 
