@@ -7,63 +7,39 @@ import os
 import sys
 import inspect
 import logging
-import numbers
-import codecs
 
-import six  # Python 3
 import time
 import datetime
 import calendar
-import omnijson as json # supports Python 2.5-3.2
-
+import pytz
 
 #
 # Python 3 
 #
 
 if sys.version < '3':
-#    import ujson as json
+    import codecs
+    import ujson as json
     from urllib import quote, quote_plus, urlencode
     from urlparse import urlsplit, urlparse
 
-    # def u(x):
-    #     if isinstance(x, str):
-    #         return x.decode('utf-8')
-    #     return x.encode('utf-8').decode('utf-8')
-                        
+    def u(x):
+        return codecs.unicode_escape_decode(x)[0]
 else:
     # ujson is faster but hasn't been ported to Python 3 yet
-#    import json
+    import json
     from urllib.parse import quote, quote_plus, urlencode, urlparse
     from urllib.parse import urlsplit
 
-    long = int
-    unicode = str
-
-    # def u(x):
-    #     return x.encode('utf-8').decode('utf-8')
-         
-         
-
-# NOTE: now using the same unicode func for both Python 2 and Python 3
-# http://stackoverflow.com/questions/6625782/unicode-literals-that-work-in-python-3-and-2
-# Unicode - see Armin's http://lucumr.pocoo.org/2013/7/2/the-updated-guide-to-unicode/
-def u(x):
-    byte_string, length = codecs.unicode_escape_encode(x)
-    unicode_string, length = codecs.unicode_escape_decode(byte_string)
-    return unicode_string
-
-
+    def u(x):
+        return x
 
 #
 # Logging
 #
 
-bulbs_logger = logging.getLogger('bulbs')
-
-def get_logger(name, level=None):
-    #logger = logging.getLogger(name)
-    logger = bulbs_logger.getChild(name)
+def get_logger(name,level=None):
+    logger = logging.getLogger(name)
     if level:
         logger.setLevel(level)
     return logger
@@ -74,13 +50,13 @@ log = get_logger(__name__)
 # Element Utils
 #
 
-
 def initialize_elements(client,response):
     # return None if there were no results; otherwise,
     # return a generator of initialized elements.
     if response.total_size > 0:
-        # yield doesn't work for conditionals
-        return (initialize_element(client, result) for result in response.results)
+        for result in response.results:
+            yield initialize_element(client,result)
+
 
 def initialize_element(client,result):
     # result should be a single Result object, not a list or generator
@@ -102,15 +78,9 @@ def get_element_key(client,result):
     var_map = dict(vertex=client.config.type_var,
                    edge=client.config.label_var)
     base_type = result.get_type()
-    if base_type == "vertex":
-        key_var = var_map[base_type]
-        # if key_var not found, just return the generic type for the Vertex
-        element_key = result.data.get(key_var, base_type)
-    elif base_type == "edge":
-        label = result.get_label()
-        element_key = label if label in client.registry.class_map else base_type
-    else:
-        raise TypeError
+    key_var = var_map[base_type]
+    # if key_var not found, just return the generic type for the Vertex/Edge class
+    element_key = result.data.get(key_var,base_type)
     return element_key
 
 # Deprecated in favor of resp.one()
@@ -142,46 +112,16 @@ def get_key_value(key, value, pair):
 # Client Utils
 #
 
-
 def build_path(*args):
+    #path = "/".join(map(str,args))
     # don't include segment if it's None
-    # quote_plus doesn't work for neo4j index lookups;
-    # for example, this won't work: index/node/test_idxV/name/James+Thornton
-    segments = [quote(to_bytes(segment), safe='') for segment in args if segment is not None]
+    segments = [str(segment) for segment in args if segment]
+    # Only need to quote URL for index keys/values -- do it at the client level
+    #segments = [quote_plus(str(segment)) for segment in args if segment]
     path = "/".join(segments)
+    # would change this to quoteplus for plus signs, but doesn't work for Neo4j
     return path
 
-def to_bytes(value):
-    # urllib does not handle Unicode at all. 
-    # URLs don't contain non-ASCII characters, by definition. 
-    # When you're dealing with urllib you should use only byte strings. 
-    # http://stackoverflow.com/a/5605354/161085
-    string_value = to_string(value)             # may have been numeric
-    unicode_value = u(string_value)             # ensure unicode
-    byte_string = unicode_value.encode('utf8')  # encode as utf8 bytestring
-    return byte_string
-
-def to_string(value):
-    # maybe convert a number to a string
-    return value if not isinstance(value, numbers.Number) else str(value)
-   
-def encode_value(value):
-    return value.encode('utf-8') if isinstance(value, str) else value
-
-def is_string(value):
-    return isinstance(value, six.string_types)
-
-def encode_dict(d):
-    for key in d:
-        val = d.pop(key)
-        #key = encode_value(key)
-        #d[key] = encode_value(val)
-        key = to_bytes(key) if is_string(key) else key
-        d[key] = to_bytes(val) if is_string(val) else val
-    return d
-        
-
-
 #
 # Time Utils
 #
@@ -198,27 +138,17 @@ def current_datetime():
     #return datetime.datetime.utcfromtimestamp(now).replace(tzinfo=pytz.utc)
     return datetime.datetime.utcfromtimestamp(now)
 
-def current_date():
-    #Return  a date object
-    return to_date(current_timestamp())
-    
 def to_timestamp(datetime):
     # Converts a datetime object to unix UTC time
     return calendar.timegm(datetime.utctimetuple()) 
 
-def to_datestamp(date):
-    # Converts a date object to unix UTC time
-    return calendar.timegm(date.timetuple()) 
-
 def to_datetime(timestamp):
     # Converts unix UTC time into a UTC datetime object
     #return datetime.datetime.utcfromtimestamp(timestamp).replace(tzinfo=pytz.utc)
     return datetime.datetime.utcfromtimestamp(timestamp)
 
-def to_date(timestamp):
-    # Converts unix UTC time into a date object
-    return datetime.date.fromtimestamp(timestamp)
-    
+
+
 # Exaplanations on dealing with time...
 
     # http://unix4lyfe.org/time/
